pecos.tools.tool\_anticommute
=============================

.. automodule:: pecos.tools.tool_anticommute

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      anticommute
   
   

   
   
   

   
   
   



